@@ -23,8 +23,8 @@ False
 """
 
 __title__ = 'starbase.conf'
-__version__ = '0.1'
-__build__ = 0x000001
+__version__ = '0.2'
+__build__ = 0x000002
 __author__ = 'Artur Barseghyan'
 __all__ = ('get_setting', 'set_setting', 'settings', 'reset_to_defaults_settings',)
 
@@ -54,7 +54,7 @@ class Settings(object):
         :param mixed default: Default value.
         :return mixed:
         """
-        if self._settings.has_key(name):
+        if name in self._settings:
             return self._settings.get(name, default)
         elif hasattr(defaults, name):
             return getattr(defaults, name, default)
